.. _tensor-array:

N-dim array
===========

.. automodule:: diofant.tensor.array

.. autoclass:: ImmutableDenseNDimArray
   :members:

.. autoclass:: ImmutableSparseNDimArray
   :members:

.. autoclass:: MutableDenseNDimArray
   :members:

.. autoclass:: MutableSparseNDimArray
   :members:
